
#
# Default values for Confero
#
# Note: This is the "global" defaults-file. Any default value set
# here can be overridden by the instance-specific defaults
# in $env(CONFERO_HOME)/tcl/defaults.tcl.
#

# User name and cname
set cname [exec $env(CONFERO_HOME)/bin/getcname]
set at_index [expr [string first "@" $cname]]
set user [string range $cname 0 [expr $at_index - 1]]

# Platform
set os_type "unknown"
set grabber_type "unknown"

#
# User's home directory can be overridden with this variable
#
# Should not be changed here, but possibly in a platform-specific defaults.tcl
#
set override_home_dir "none"

# Video constants
set NTSC 2
set PAL 4
set COMPOSITE 2
set SVIDEO 3
set YUV 4
set RGB 5

set PAL_FULL_WIDTH 768
set PAL_FULL_HEIGHT 576
set NTSC_FULL_WIDTH 640
set NTSC_FULL_HEIGHT 480

# Audio constants
set LINE_IN 2
set MICROPHONE 1
set LINE_OUT 4
set SPEAKER 1
set HEADPHONES 2

#
# Session parameters
#

#
# These can be set by the command-line arguments (-a, -p) or in the
# platform-specific defaults.tcl file.
#
# Default destination address (or hostname)
if {![info exists IP_ADDR]} {
  set IP_ADDR "224.2.2.2"
  set addr_set_on_cmdline 0
} else {
  set addr_set_on_cmdline 1
}

# Default destination UDP port number
if {![info exists PORT]} {
  set PORT 5566
  set port_set_on_cmdline 0
} else {
  set port_set_on_cmdline 1
}

#Default text messaging port number
set default_txt_msg_port 12000

#Default file transfer port number
set default_ft_port 12001

# Default behavior of Enter-key in text messaging
set default_txt_msg_enter_sends 1

# Default time-to-live (for multicast only)
set TTL 15

set REFLEX_PORT 5150
if { [catch { set f [open "$env(CONFERO_HOME)/info/dest.rc"]}] } {
  set default_destinations {"localhost"}
} else {
  set default_destinations [read $f]
  close $f
}

#
# Display session parameters selection box at startup?
#
set use_preconfig_session_params 0

#
# Default is to use reflector?
#
set default_use_reflector 0

#
# Default size of transmitted video (small, medium, large or huge)
#
set default_resolution medium

#
# Default video server parameters
#
set default_video_server jimi
set default_video_server_port 4444

set default_streaming_address 224.2.2.2
set default_streaming_port 5566

#
# Default video signal parameters
#
set default_video_standard $PAL
set default_video_format $COMPOSITE
set default_video_input 1

#
# default audio parameters
#

# Enable/disable Audio Configuration panel
set audio_conf_enabled 0

# Default audio input/output
set default_audio_input 1
set default_audio_output 2

# Default volume/mic gain
set default_volume 70
set default_mic_gain 70


# Silence sensor on/off, threshold value, automatic silence level detection
set default_silence 0
set default_silence_threshold 50
set default_sil_auto 0
# Net-mutes-mike on/off, threshold value
set default_nmm 0
set default_nmm_threshold 50
set default_nmma 0

# Audio encodings
set GSM 3
set DVI 6
set PCM 11
set G722 9
set default_audio_encoding $PCM

# Enable some features used in scalable layered multicast mode
set scale_version [session scalability]

# Default Quality and frame rate
set default_framerate 25
set default_quality 50

# Automatically start transmitting audio
set automatic_audio_xmit 1

# Automatically start transmitting video
set automatic_video_xmit 0

# Automatically start displaying received video
set automatic_video_recv 1

# Should the video transmitter window start in muted mode?
set default_is_start_muted 0

#Enable logging
set log_level 0
set logfile $env(CONFERO_HOME)/info/log
set log_format normal

#Alternative video input ctrl
set use_alt_video_ctrls 0

# Tools to be included on the toolbar
set include_video_on_toolbar 1
set include_audio_on_toolbar 1
set include_smedia_on_toolbar 1
set include_wb_on_toolbar 0
set include_txtmsg_on_toolbar 1
set include_sip_on_toolbar 0
set include_appshare_on_toolbar 1
set include_file_transfer_on_toolbar 1

#Default equation-based congestion control algorithm
set default_eqbcc 1

#Default remote camera control TCP port
set default_rcam_port 3399

#Service classes for audio and video in the Reflex reflector
set reflex_video_service_class 6
set reflex_audio_service_class 5

#Service classes for audio and video streaming from servo via reflector
set default_audio_streaming_service_class 10
set default_video_streaming_service_class 9

#Default playback speed for streaming media
set default_vserv_playback_speed "100%"

# The lowest version of sserv required by Confero
set sserv_required_version 0.3

# default serial port for remote camera control, 1=COM1, 2=COM2, 0=Disable
set default_rcam_serial 2
 
# Default video transmitter menu options
set vtm_annotations 0
set vtm_fec 1
set vtm_pause 1
set vtm_size 1
set vtm_localscaling 1
set vtm_mirror 0
set vtm_flip 0
set vtm_camtype 1
set vtm_inputnr 0
set vtm_inputtype 1
set vtm_stereo true
set vtm_qualband 1
set vtm_size_small 1
set vtm_compression 1
set vtm_preprocessing 0
set vtm_chroma_keying 0
set vtm_captioning 0
set vtm_alt_local_rendering 1
set vtm_qcam 0
set vtm_rtpmanup 0
set vtm_crop 0
set vtm_rtppadding 1
set vtm_static_image 1
set vtm_fullscreen 0

# Default video receiver menu options
set vrm_size 1
set vrm_request_size 1
set vrm_noframe 1
set vrm_nomenubar 1
set vrm_camctl 1
set vrm_statistics 1
set vrm_avsync 1
set vrm_mirror 0
set vrm_rotate 0
set vrm_output 0
set vrm_annotations 0
set vrm_postprocessing 0
set vrm_alt_rendering 0
set vrm_fullscreen 0
set vrm_save_to_file 1

# Video compression algorithms supported on all platforms
set video_compression_algorithms {JPEG}

# Default video compression algorithm
set default_video_compression JPEG

# Default background color
set bgcolor #d9d9d9

# Default values for quickcam pro 4000 usb camera
set default_brightness 50
set default_contrast 50
set default_colour 50
set default_hue 50
set default_whitness 50
set default_agc 1
set default_agc_value 10
set default_wb 0
set default_bcm 1
set default_afm 1
set default_dnr 1
# End qcam pro 4000

set default_rtp_offset 0

set firewall_traversal_support 0

# Show reflector admin interface?
set include_reflector_admin 0

# Camera type is used to discriminate among different USB cameras
set camera_type "generic"

# Watchdog for alleviating strange bug with Matrox Meteor grabber
set matrox_watchdog 0

# Default session name and bandwidth limit when using reflector
set default_reflex_session_name "confero"
set default_reflex_bw 0

# RTP padding
set use_rtp_video_padding 0

# Interframe keyframe distance for MPEG-2 and H.264
set default_i_p_dist 6

# Should the user be asked to enter a password when the VNC-server is started by Confero?
set ask_for_vnc_password 0

# Share applictions from remote host?
set share_remote_applications 0
set remote_appshare_host ""
set remote_appshare_password ""

#Include the control interface for the Gentner AP400 echo canceler
set include_gentner_interface 0
set gentner_serial_port "COM1"
set gentner_baudrate 9600

# Always refuse resolution change requests from remote users?
set refuse_res_change_requests 0

# Default video bandwidth limit (when traffic shaping is enabled)
set default_bw_limit 10000

# Is traffic shaping for video enabled by default?
set default_do_shaping 1

# Default user level: 0 = beginner, 1 = standard, 3 = expert
set user_level 1

# Main window heading
set main_win_heading "Conference Participants:"

# Use UltraVNC viewer instead of good old vncviewer?
set appshare_use_ultravnc 0

# Output debug messages from video grabber code?
set grabber_debug 0

# Show advanced audio controls by default?
set audio_show_advanced_controls_default 0

# Server providing IP address of connecting clients (checkip.alkit.se)
set public_ip_address_server checkip.alkit.se
